@@ -9,11 +9,13 @@ use Wx ':everything';
 use Wx::Html ();
 use Wx::Locale ();
 
-our $VERSION = '0.63';
+our $VERSION = '0.64';
 our @ISA     = 'Wx::App';
 
 sub run {
-	shift->new(@_)->MainLoop;
+	my $class = shift;
+	my $self  = $class->new(@_);
+	return $self->MainLoop;
 }
 
 sub OnInit {
